==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/ExpressRouteCrossConnectionPeering.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin

import com.pulumi.azurenative.network.kotlin.outputs.ExpressRouteCircuitPeeringConfigResponse
import com.pulumi.azurenative.network.kotlin.outputs.Ipv6ExpressRouteCircuitPeeringConfigResponse
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.Double
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import com.pulumi.azurenative.network.kotlin.outputs.ExpressRouteCircuitPeeringConfigResponse.Companion.toKotlin as expressRouteCircuitPeeringConfigResponseToKotlin
import com.pulumi.azurenative.network.kotlin.outputs.Ipv6ExpressRouteCircuitPeeringConfigResponse.Companion.toKotlin as ipv6ExpressRouteCircuitPeeringConfigResponseToKotlin

/**
 * Builder for [ExpressRouteCrossConnectionPeering].
 */
@PulumiTagMarker
public class ExpressRouteCrossConnectionPeeringResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: ExpressRouteCrossConnectionPeeringArgs = ExpressRouteCrossConnectionPeeringArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend ExpressRouteCrossConnectionPeeringArgsBuilder.() -> Unit) {
        val builder = ExpressRouteCrossConnectionPeeringArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.opts(block)
    }

    internal fun build(): ExpressRouteCrossConnectionPeering {
        val builtJavaResource =
            com.pulumi.azurenative.network.ExpressRouteCrossConnectionPeering(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return ExpressRouteCrossConnectionPeering(builtJavaResource)
    }
}

/**
 * Peering in an ExpressRoute Cross Connection resource.
 * Azure REST API version: 2023-02-01. Prior API version in Azure Native 1.x: 2020-11-01.
 * Other available API versions: 2019-08-01, 2023-04-01, 2023-05-01, 2023-06-01.
 * ## Example Usage
 * ### ExpressRouteCrossConnectionBgpPeeringCreate
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var expressRouteCrossConnectionPeering = new AzureNative.Network.ExpressRouteCrossConnectionPeering("expressRouteCrossConnectionPeering", new()
 *     {
 *         CrossConnectionName = "<circuitServiceKey>",
 *         Ipv6PeeringConfig = new AzureNative.Network.Inputs.Ipv6ExpressRouteCircuitPeeringConfigArgs
 *         {
 *             PrimaryPeerAddressPrefix = "3FFE:FFFF:0:CD30::/126",
 *             SecondaryPeerAddressPrefix = "3FFE:FFFF:0:CD30::4/126",
 *         },
 *         PeerASN = 200,
 *         PeeringName = "AzurePrivatePeering",
 *         PrimaryPeerAddressPrefix = "192.168.16.252/30",
 *         ResourceGroupName = "CrossConnection-SiliconValley",
 *         SecondaryPeerAddressPrefix = "192.168.18.252/30",
 *         VlanId = 200,
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/network/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := network.NewExpressRouteCrossConnectionPeering(ctx, "expressRouteCrossConnectionPeering", &network.ExpressRouteCrossConnectionPeeringArgs{
 * 			CrossConnectionName: pulumi.String("<circuitServiceKey>"),
 * 			Ipv6PeeringConfig: &network.Ipv6ExpressRouteCircuitPeeringConfigArgs{
 * 				PrimaryPeerAddressPrefix:   pulumi.String("3FFE:FFFF:0:CD30::/126"),
 * 				SecondaryPeerAddressPrefix: pulumi.String("3FFE:FFFF:0:CD30::4/126"),
 * 			},
 * 			PeerASN:                    pulumi.Float64(200),
 * 			PeeringName:                pulumi.String("AzurePrivatePeering"),
 * 			PrimaryPeerAddressPrefix:   pulumi.String("192.168.16.252/30"),
 * 			ResourceGroupName:          pulumi.String("CrossConnection-SiliconValley"),
 * 			SecondaryPeerAddressPrefix: pulumi.String("192.168.18.252/30"),
 * 			VlanId:                     pulumi.Int(200),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.network.ExpressRouteCrossConnectionPeering;
 * import com.pulumi.azurenative.network.ExpressRouteCrossConnectionPeeringArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var expressRouteCrossConnectionPeering = new ExpressRouteCrossConnectionPeering("expressRouteCrossConnectionPeering", ExpressRouteCrossConnectionPeeringArgs.builder()
 *             .crossConnectionName("<circuitServiceKey>")
 *             .ipv6PeeringConfig(Map.ofEntries(
 *                 Map.entry("primaryPeerAddressPrefix", "3FFE:FFFF:0:CD30::/126"),
 *                 Map.entry("secondaryPeerAddressPrefix", "3FFE:FFFF:0:CD30::4/126")
 *             ))
 *             .peerASN(200)
 *             .peeringName("AzurePrivatePeering")
 *             .primaryPeerAddressPrefix("192.168.16.252/30")
 *             .resourceGroupName("CrossConnection-SiliconValley")
 *             .secondaryPeerAddressPrefix("192.168.18.252/30")
 *             .vlanId(200)
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:network:ExpressRouteCrossConnectionPeering AzurePrivatePeering /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/expressRouteCrossConnections/{crossConnectionName}/peerings/{peeringName}
 * ```
 */
public class ExpressRouteCrossConnectionPeering internal constructor(
    override val javaResource: com.pulumi.azurenative.network.ExpressRouteCrossConnectionPeering,
) : KotlinCustomResource(javaResource, ExpressRouteCrossConnectionPeeringMapper) {
    /**
     * The Azure ASN.
     */
    public val azureASN: Output<Int>
        get() = javaResource.azureASN().applyValue({ args0 -> args0 })

    /**
     * A unique read-only string that changes whenever the resource is updated.
     */
    public val etag: Output<String>
        get() = javaResource.etag().applyValue({ args0 -> args0 })

    /**
     * The GatewayManager Etag.
     */
    public val gatewayManagerEtag: Output<String>?
        get() = javaResource.gatewayManagerEtag().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * The IPv6 peering configuration.
     */
    public val ipv6PeeringConfig: Output<Ipv6ExpressRouteCircuitPeeringConfigResponse>?
        get() = javaResource.ipv6PeeringConfig().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.let({ args0 ->
                    ipv6ExpressRouteCircuitPeeringConfigResponseToKotlin(args0)
                })
            }).orElse(null)
        })

    /**
     * Who was the last to modify the peering.
     */
    public val lastModifiedBy: Output<String>
        get() = javaResource.lastModifiedBy().applyValue({ args0 -> args0 })

    /**
     * The Microsoft peering configuration.
     */
    public val microsoftPeeringConfig: Output<ExpressRouteCircuitPeeringConfigResponse>?
        get() = javaResource.microsoftPeeringConfig().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.let({ args0 ->
                    expressRouteCircuitPeeringConfigResponseToKotlin(args0)
                })
            }).orElse(null)
        })

    /**
     * The name of the resource that is unique within a resource group. This name can be used to access the resource.
     */
    public val name: Output<String>?
        get() = javaResource.name().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * The peer ASN.
     */
    public val peerASN: Output<Double>?
        get() = javaResource.peerASN().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * The peering type.
     */
    public val peeringType: Output<String>?
        get() = javaResource.peeringType().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * The primary port.
     */
    public val primaryAzurePort: Output<String>
        get() = javaResource.primaryAzurePort().applyValue({ args0 -> args0 })

    /**
     * The primary address prefix.
     */
    public val primaryPeerAddressPrefix: Output<String>?
        get() = javaResource.primaryPeerAddressPrefix().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * The provisioning state of the express route cross connection peering resource.
     */
    public val provisioningState: Output<String>
        get() = javaResource.provisioningState().applyValue({ args0 -> args0 })

    /**
     * The secondary port.
     */
    public val secondaryAzurePort: Output<String>
        get() = javaResource.secondaryAzurePort().applyValue({ args0 -> args0 })

    /**
     * The secondary address prefix.
     */
    public val secondaryPeerAddressPrefix: Output<String>?
        get() = javaResource.secondaryPeerAddressPrefix().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * The shared key.
     */
    public val sharedKey: Output<String>?
        get() = javaResource.sharedKey().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * The peering state.
     */
    public val state: Output<String>?
        get() = javaResource.state().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * The VLAN ID.
     */
    public val vlanId: Output<Int>?
        get() = javaResource.vlanId().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })
}

public object ExpressRouteCrossConnectionPeeringMapper :
    ResourceMapper<ExpressRouteCrossConnectionPeering> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.network.ExpressRouteCrossConnectionPeering::class == javaResource::class

    override fun map(javaResource: Resource): ExpressRouteCrossConnectionPeering =
        ExpressRouteCrossConnectionPeering(
            javaResource as
                com.pulumi.azurenative.network.ExpressRouteCrossConnectionPeering,
        )
}

/**
 * @see [ExpressRouteCrossConnectionPeering].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [ExpressRouteCrossConnectionPeering].
 */
public suspend fun expressRouteCrossConnectionPeering(
    name: String,
    block: suspend ExpressRouteCrossConnectionPeeringResourceBuilder.() -> Unit,
):
    ExpressRouteCrossConnectionPeering {
    val builder = ExpressRouteCrossConnectionPeeringResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [ExpressRouteCrossConnectionPeering].
 * @param name The _unique_ name of the resulting resource.
 */
public fun expressRouteCrossConnectionPeering(name: String): ExpressRouteCrossConnectionPeering {
    val builder = ExpressRouteCrossConnectionPeeringResourceBuilder()
    builder.name(name)
    return builder.build()
}

==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/ExpressRouteCrossConnectionPeering.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin

import com.pulumi.azurenative.network.kotlin.outputs.ExpressRouteCircuitPeeringConfigResponse
import com.pulumi.azurenative.network.kotlin.outputs.Ipv6ExpressRouteCircuitPeeringConfigResponse
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.Double
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import com.pulumi.azurenative.network.kotlin.outputs.ExpressRouteCircuitPeeringConfigResponse.Companion.toKotlin as expressRouteCircuitPeeringConfigResponseToKotlin
import com.pulumi.azurenative.network.kotlin.outputs.Ipv6ExpressRouteCircuitPeeringConfigResponse.Companion.toKotlin as ipv6ExpressRouteCircuitPeeringConfigResponseToKotlin

/**
 * Builder for [ExpressRouteCrossConnectionPeering].
 */
@PulumiTagMarker
public class ExpressRouteCrossConnectionPeeringResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: ExpressRouteCrossConnectionPeeringArgs = ExpressRouteCrossConnectionPeeringArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend ExpressRouteCrossConnectionPeeringArgsBuilder.() -> Unit) {
        val builder = ExpressRouteCrossConnectionPeeringArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.opts(block)
    }

    internal fun build(): ExpressRouteCrossConnectionPeering {
        val builtJavaResource =
            com.pulumi.azurenative.network.ExpressRouteCrossConnectionPeering(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return ExpressRouteCrossConnectionPeering(builtJavaResource)
    }
}

/**
 * Peering in an ExpressRoute Cross Connection resource.
 * Azure REST API version: 2023-02-01. Prior API version in Azure Native 1.x: 2020-11-01.
 * Other available API versions: 2019-08-01, 2023-04-01, 2023-05-01, 2023-06-01, 2023-09-01.
 * ## Example Usage
 * ### ExpressRouteCrossConnectionBgpPeeringCreate
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var expressRouteCrossConnectionPeering = new AzureNative.Network.ExpressRouteCrossConnectionPeering("expressRouteCrossConnectionPeering", new()
 *     {
 *         CrossConnectionName = "<circuitServiceKey>",
 *         Ipv6PeeringConfig = new AzureNative.Network.Inputs.Ipv6ExpressRouteCircuitPeeringConfigArgs
 *         {
 *             PrimaryPeerAddressPrefix = "3FFE:FFFF:0:CD30::/126",
 *             SecondaryPeerAddressPrefix = "3FFE:FFFF:0:CD30::4/126",
 *         },
 *         PeerASN = 200,
 *         PeeringName = "AzurePrivatePeering",
 *         PrimaryPeerAddressPrefix = "192.168.16.252/30",
 *         ResourceGroupName = "CrossConnection-SiliconValley",
 *         SecondaryPeerAddressPrefix = "192.168.18.252/30",
 *         VlanId = 200,
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/network/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := network.NewExpressRouteCrossConnectionPeering(ctx, "expressRouteCrossConnectionPeering", &network.ExpressRouteCrossConnectionPeeringArgs{
 * 			CrossConnectionName: pulumi.String("<circuitServiceKey>"),
 * 			Ipv6PeeringConfig: &network.Ipv6ExpressRouteCircuitPeeringConfigArgs{
 * 				PrimaryPeerAddressPrefix:   pulumi.String("3FFE:FFFF:0:CD30::/126"),
 * 				SecondaryPeerAddressPrefix: pulumi.String("3FFE:FFFF:0:CD30::4/126"),
 * 			},
 * 			PeerASN:                    pulumi.Float64(200),
 * 			PeeringName:                pulumi.String("AzurePrivatePeering"),
 * 			PrimaryPeerAddressPrefix:   pulumi.String("192.168.16.252/30"),
 * 			ResourceGroupName:          pulumi.String("CrossConnection-SiliconValley"),
 * 			SecondaryPeerAddressPrefix: pulumi.String("192.168.18.252/30"),
 * 			VlanId:                     pulumi.Int(200),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.network.ExpressRouteCrossConnectionPeering;
 * import com.pulumi.azurenative.network.ExpressRouteCrossConnectionPeeringArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var expressRouteCrossConnectionPeering = new ExpressRouteCrossConnectionPeering("expressRouteCrossConnectionPeering", ExpressRouteCrossConnectionPeeringArgs.builder()
 *             .crossConnectionName("<circuitServiceKey>")
 *             .ipv6PeeringConfig(Map.ofEntries(
 *                 Map.entry("primaryPeerAddressPrefix", "3FFE:FFFF:0:CD30::/126"),
 *                 Map.entry("secondaryPeerAddressPrefix", "3FFE:FFFF:0:CD30::4/126")
 *             ))
 *             .peerASN(200)
 *             .peeringName("AzurePrivatePeering")
 *             .primaryPeerAddressPrefix("192.168.16.252/30")
 *             .resourceGroupName("CrossConnection-SiliconValley")
 *             .secondaryPeerAddressPrefix("192.168.18.252/30")
 *             .vlanId(200)
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:network:ExpressRouteCrossConnectionPeering AzurePrivatePeering /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/expressRouteCrossConnections/{crossConnectionName}/peerings/{peeringName}
 * ```
 */
public class ExpressRouteCrossConnectionPeering internal constructor(
    override val javaResource: com.pulumi.azurenative.network.ExpressRouteCrossConnectionPeering,
) : KotlinCustomResource(javaResource, ExpressRouteCrossConnectionPeeringMapper) {
    /**
     * The Azure ASN.
     */
    public val azureASN: Output<Int>
        get() = javaResource.azureASN().applyValue({ args0 -> args0 })

    /**
     * A unique read-only string that changes whenever the resource is updated.
     */
    public val etag: Output<String>
        get() = javaResource.etag().applyValue({ args0 -> args0 })

    /**
     * The GatewayManager Etag.
     */
    public val gatewayManagerEtag: Output<String>?
        get() = javaResource.gatewayManagerEtag().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * The IPv6 peering configuration.
     */
    public val ipv6PeeringConfig: Output<Ipv6ExpressRouteCircuitPeeringConfigResponse>?
        get() = javaResource.ipv6PeeringConfig().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.let({ args0 ->
                    ipv6ExpressRouteCircuitPeeringConfigResponseToKotlin(args0)
                })
            }).orElse(null)
        })

    /**
     * Who was the last to modify the peering.
     */
    public val lastModifiedBy: Output<String>
        get() = javaResource.lastModifiedBy().applyValue({ args0 -> args0 })

    /**
     * The Microsoft peering configuration.
     */
    public val microsoftPeeringConfig: Output<ExpressRouteCircuitPeeringConfigResponse>?
        get() = javaResource.microsoftPeeringConfig().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.let({ args0 ->
                    expressRouteCircuitPeeringConfigResponseToKotlin(args0)
                })
            }).orElse(null)
        })

    /**
     * The name of the resource that is unique within a resource group. This name can be used to access the resource.
     */
    public val name: Output<String>?
        get() = javaResource.name().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * The peer ASN.
     */
    public val peerASN: Output<Double>?
        get() = javaResource.peerASN().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * The peering type.
     */
    public val peeringType: Output<String>?
        get() = javaResource.peeringType().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * The primary port.
     */
    public val primaryAzurePort: Output<String>
        get() = javaResource.primaryAzurePort().applyValue({ args0 -> args0 })

    /**
     * The primary address prefix.
     */
    public val primaryPeerAddressPrefix: Output<String>?
        get() = javaResource.primaryPeerAddressPrefix().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * The provisioning state of the express route cross connection peering resource.
     */
    public val provisioningState: Output<String>
        get() = javaResource.provisioningState().applyValue({ args0 -> args0 })

    /**
     * The secondary port.
     */
    public val secondaryAzurePort: Output<String>
        get() = javaResource.secondaryAzurePort().applyValue({ args0 -> args0 })

    /**
     * The secondary address prefix.
     */
    public val secondaryPeerAddressPrefix: Output<String>?
        get() = javaResource.secondaryPeerAddressPrefix().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * The shared key.
     */
    public val sharedKey: Output<String>?
        get() = javaResource.sharedKey().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * The peering state.
     */
    public val state: Output<String>?
        get() = javaResource.state().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * The VLAN ID.
     */
    public val vlanId: Output<Int>?
        get() = javaResource.vlanId().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })
}

public object ExpressRouteCrossConnectionPeeringMapper :
    ResourceMapper<ExpressRouteCrossConnectionPeering> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.network.ExpressRouteCrossConnectionPeering::class == javaResource::class

    override fun map(javaResource: Resource): ExpressRouteCrossConnectionPeering =
        ExpressRouteCrossConnectionPeering(
            javaResource as
                com.pulumi.azurenative.network.ExpressRouteCrossConnectionPeering,
        )
}

/**
 * @see [ExpressRouteCrossConnectionPeering].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [ExpressRouteCrossConnectionPeering].
 */
public suspend fun expressRouteCrossConnectionPeering(
    name: String,
    block: suspend ExpressRouteCrossConnectionPeeringResourceBuilder.() -> Unit,
):
    ExpressRouteCrossConnectionPeering {
    val builder = ExpressRouteCrossConnectionPeeringResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [ExpressRouteCrossConnectionPeering].
 * @param name The _unique_ name of the resulting resource.
 */
public fun expressRouteCrossConnectionPeering(name: String): ExpressRouteCrossConnectionPeering {
    val builder = ExpressRouteCrossConnectionPeeringResourceBuilder()
    builder.name(name)
    return builder.build()
}
